[![documentation](https://img.shields.io/badge/documentation-html-informational)](https://jlecomte.gitlab.io/projects/python/flasket)
[![license](https://img.shields.io/badge/license-MIT-brightgreen)](https://spdx.org/licenses/MIT.html)
[![pipelines](https://gitlab.com/jlecomte/projects/python/flasket/badges/master/pipeline.svg)](https://gitlab.com/jlecomte/projects/python/flasket/pipelines)
[![coverage](https://gitlab.com/jlecomte/projects/python/flasket/badges/master/coverage.svg)](https://jlecomte.gitlab.io/projects/python/flasket/coverage/index.html)

# Flasket

A small flask.

A flask + connexion ensemble to quickly deploy an app.

## Installation from PyPI

You can install the latest version from PyPI package repository.

~~~bash
python3 -mpip install -U flasket
~~~

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Locations

  * Documentation: [https://jlecomte.gitlab.io/projects/python/flasket/](https://jlecomte.gitlab.io/projects/python/flasket)
  * GitLab: [https://gitlab.com/jlecomte/projects/python/flasket](https://gitlab.com/jlecomte/projects/python/flasket)
  * PyPi: [https://pypi.org/project/flasket](https://pypi.org/project/flasket)
